@@ -91,7 +91,12 @@ def get_comment_total_by_post_item(post_item):
 # 获取comment
 def get_comment_item_by_id_and_domain_id(comment_id, domain_id):
     col = get_col("results_comments")
-    comment_result = col.find_one({"comment_id": comment_id, "domain_id": domain_id})
+    condition = {}
+    if comment_id:
+        condition['comment_id'] = comment_id
+    if domain_id:
+        condition['domain_id'] = domain_id
+    comment_result = col.find_one(condition)
     return comment_result
 
 
